/*
 #######################################################
 Project: chipKIT Uno32 Light Meter
 Description: This project measures ambient light intensity and displays it on an OLED
              display in Lux, Foot Candle, and Watts/m^2 units. The BH1750 sensor is used for
              measuring light intensity. The range of the meter is 0-54612 Lux, and resolution is 1 Lux.
 Written by: Raj Bhatt (April 17, 2014)
 www.embedded-lab.com
 #######################################################
 
 BH1750 sensor module connections:
 -------------------------------------
 BH1750                        chipKIT Uno32
 VCC      --------------->     3.3V
 SCL      --------------->     Analog pin 5 (A5)
 SDA      --------------->     Analog pin 4 (A4)
 ADD      --------------->     Leave it open
 GND      --------------->     GND
 #######################################################
   
 This software is licensed under a 
 Creative Commons Attribution-ShareAlike 3.0. 
 */


#include <Wire.h> 
#include <math.h>
#include <IOShieldOled.h>
#include <Wprogram.h>
#include <WString.h> 
#define  OLED  IOShieldOledClass

#define cbOledChar      8                //number of bytes in a glyph
#define cbOledFontUser  (32*cbOledChar)  //number of bytes in user font table

int BH1750_Device = 0x23; // I2C address for light sensor
int iCheck = 0;  // iCheck = 0 for Lux, iCheck = 1 for Foot-Candles
unsigned int Lux, Scaled_FtCd, ones, tens, hundreds;
float FtCd, Wattm2;

//variables to keep track of the timing of recent interrupts
unsigned long button_time = 0;  
unsigned long last_button_time = 0; 
char strheart[6];
OLED  oled;
void setup()
{
  Wire.begin();
  Serial.begin(9600);
  Configure_BH1750();
  oled.begin();
  delay(300);
  
}

void loop()
{
  int i;
  Lux = BH1750_Read();
  FtCd = Lux/10.764;
  Wattm2 = Lux/683.002;
  Serial.print(Lux,DEC);     
  Serial.println("[lx]"); 
  Serial.print(FtCd,3);     
  Serial.println("[FC]");
  Serial.print(Wattm2,3);     
  Serial.println("[W/m^2]");
  Disp_Data();
  delay(3000); 
}

unsigned int BH1750_Read() //
{
  unsigned int i=0;
  Wire.beginTransmission(BH1750_Device);
  Wire.requestFrom(BH1750_Device, 2);
  while(Wire.available()) //
  {
    i <<=8;
    i|= Wire.receive();  
  }
  Wire.endTransmission();  
  return i/1.2;  // Convert to Lux
}

void Disp_Data(){
  oled.clear();
  oled.setCursor(0, 0);
  oled.putString("Light Meter");
  
  // Display LUX
  IOShieldOled.setCursor(0, 1);
  IOShieldOled.putString("LUX:   ");
  
  String Lux_num; 
  Lux_num = int(Lux);
  char Lux_chr[Lux_num.length()+1]; //create char buffer
  Lux_num.toCharArray(Lux_chr, Lux_num.length()+1); //convert to char
  IOShieldOled.putString(Lux_chr);
  
  // Display Footcandles
  IOShieldOled.setCursor(0, 2);
  IOShieldOled.putString("Ft-Cd: ");
  
  String FtCd_num; 
  FtCd_num = int(FtCd*1000)/1000;
  char FtCd_numchr[FtCd_num.length()+1]; //create char buffer
  FtCd_num.toCharArray(FtCd_numchr, FtCd_num.length()+1); //convert to char
  IOShieldOled.putString(FtCd_numchr);
  IOShieldOled.putString(".");  // Print decimal symbol
  int FtCd_rem = int(FtCd*1000)%1000;
  ones = FtCd_rem%10;
  FtCd_rem = FtCd_rem/10;
  tens = FtCd_rem%10;
  FtCd_rem = FtCd_rem/10;
  hundreds = FtCd_rem%10;
  
  //convert data to ASCII
  hundreds = hundreds+48;
  tens = tens+48;
  ones = ones+48;
  IOShieldOled.putChar(hundreds);
  IOShieldOled.putChar(tens);
  IOShieldOled.putChar(ones);
  
  // Display Watts/m^2
  IOShieldOled.setCursor(0, 3);
  IOShieldOled.putString("W/m^2: ");
  
  String Watt_num; 
  Watt_num = int(Wattm2*1000)/1000;
  char Watt_numchr[Watt_num.length()+1]; //create char buffer
  Watt_num.toCharArray(Watt_numchr, Watt_num.length()+1); //convert to char
  IOShieldOled.putString(Watt_numchr);
  IOShieldOled.putString(".");  // Print decimal symbol
  int Watt_rem = int(Wattm2*1000)%1000;
  ones = Watt_rem%10;
  Watt_rem = Watt_rem/10;
  tens = Watt_rem%10;
  Watt_rem = Watt_rem/10;
  hundreds = Watt_rem%10;
  
  //convert data to ASCII
  hundreds = hundreds+48;
  tens = tens+48;
  ones = ones+48;
  IOShieldOled.putChar(hundreds);
  IOShieldOled.putChar(tens);
  IOShieldOled.putChar(ones);
 
}

void Configure_BH1750() 
{
  Wire.beginTransmission(BH1750_Device);
  Wire.send(0x10);      // Set resolution to 1 Lux
  Wire.endTransmission();
}



